<p>
    <picture>
        <source media="(prefers-color-scheme: dark)" srcset=".graphics/svg/logo_white.svg" width=100>
        <img src=".graphics/svg/logo_black.svg" width=100>
    </picture>
</p>

# Trackteroid

[![Documentation Status][documentation-button]][documentation]
[![Python Versions][pyversion-button]][pypi]
[![BSD License][bsdlicense-button]][bsdlicense]

[documentation]: https://trackteroid.readthedocs.io
[documentation-button]: https://readthedocs.org/projects/trackteroid/badge/?version=latest
[pyversion-button]: https://img.shields.io/pypi/pyversions/Trackteroid.svg
[pypi]: https://pypi.org/project/trackteroid/
[bsdlicense]: https://opensource.org/licenses/BSD-3-Clause
[bsdlicense-button]: https://img.shields.io/badge/license-BSD-yellow.svg

----
**Declarative, object-oriented wrapper for Ftrack queries. Powerful functional-style interactions with resulting collections.**
